| hobbs_check_sampler | R Documentation |
Checks whether the sampler installed with the package exists and can be
started with --help. Does not require Rust, build a sampler, or modify the
user cache. A C compiler is checked separately when compiling a model.
hobbs_check_sampler(quiet = FALSE)
quiet |
Logical. If |
Invisibly returns TRUE when the installed sampler starts
successfully, and FALSE otherwise.
library(hobbs)
hobbs_check_sampler()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.